Crate bevy_child_window

Crate bevy_child_window 

Provides the feature to create a child window

You can create a child window by inserting ParentWindow. The window belonging to the same entity as its component will be displayed within the area of the parent window.

Example

use bevy::prelude::*;
use bevy_child_window::ParentWindow;

fn spawn_child_window(
    mut commands: Commands,
   parent_window: Query<Entity, With<ParentWindow>>,
){
    commands.spawn((
        ParentWindow(parent_window.single().expect("Parent not found")),
        Window::default(),
   ));
}

Modules

prelude

Structs

ChildWindowPlugin
Provides the feature to create a child window
ParentWindow
Specifies the entity of the parent window.