pub struct ChildWindowPlugin;Expand description
Provides the feature to create a child window
You can create a child window by inserting ParentWindow.
The window belonging to the same entity as its component will be displayed within the area of the parent window.
Example
use bevy::prelude::*;
use bevy_child_window::ParentWindow;
fn spawn_child_window(
mut commands: Commands,
parent_window: Query<Entity, With<ParentWindow>>,
){
commands.spawn((
ParentWindow(parent_window.single().expect("Parent not found")),
Window::default(),
));
}Trait Implementations
Sourceimpl Plugin for ChildWindowPlugin
impl Plugin for ChildWindowPlugin
Sourcefn ready(&self, _app: &App) -> bool
fn ready(&self, _app: &App) -> bool
Has the plugin finished its setup? This can be useful for plugins that need something
asynchronous to happen before they can finish their setup, like the initialization of a renderer.
Once the plugin is ready,
finish should be called.Sourcefn finish(&self, _app: &mut App)
fn finish(&self, _app: &mut App)
Finish adding this plugin to the
App, once all plugins registered are ready. This can
be useful for plugins that depends on another plugin asynchronous setup, like the renderer.Sourcefn cleanup(&self, _app: &mut App)
fn cleanup(&self, _app: &mut App)
Runs after all plugins are built and finished, but before the app schedule is executed.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.